/* ----------------------------------------------------------------------------
 *
 * Raima Database Manager
 *
 * Copyright (c) 2012 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 *
 * ----------------------------------------------------------------------------
 */

/* EXAMPLE - obj07 for C */
/* This is the DDL (Database Definition Language) for a database implementing
 * a many-to-many relationship using network model sets.  The database shows
 * how to implement a course registration list with Students that attend
 * multiple Classes and Classes that are attended by multiple Students.
 * 
 * The student record has a single Name field
 * The course record has an ID and Title field
 * There is an intersection (registrations) record that does not contain any 
 * user fields
 *
 * This schema file should be processed using the ddlp utility using the
 * -c, -cpp,  and -d options to create an embedded dbd file.  The -c option 
 * will generate a c header file (obj07_db_dbd.h) and a c source file 
 * (obj07_db_dbd.c) which can be compiled into the application and used with 
 * the db.Open Method to create the database if it does not already exist.
 */

database obj07_db 
{
    data file "obj07_db.d01" contains student;
    data file "obj07_db.d02" contains course;
    data file "obj07_db.d03" contains course_registration;
    key  file "obj07_db.k01" contains name;
    key  file "obj07_db.k02" contains id;

    record student 
    {
        unique key char name[100];
    }
    
    record course 
    {
        unique key char id[10];
        char title[100];
    }
    
    record course_registration 
    {
    }

    set attends
    {
       order  last;
       owner  student;
       member course_registration;
    }

    set attended_by
    {
       order  last;
       owner  course;
       member course_registration;
    }
}


